#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['uptodate', 'uptodate.tests']

package_data = \
{'': ['*'],
 'uptodate': ['.cache/*',
              '.cache/v/*',
              '.cache/v/cache/*',
              '.mypy_cache/*',
              '.mypy_cache/3.6/*',
              '.mypy_cache/3.6/click/*',
              '.mypy_cache/3.6/collections/*',
              '.mypy_cache/3.6/distutils/*',
              '.mypy_cache/3.6/tests/*']}

install_requires = \
['typer==0.2.1', 'requests==2.23.0', 'rich==2.0.0']

entry_points = \
{'console_scripts': ['uptodate = uptodate.cli']}

setup(name='uptodate',
      version='0.3.1',
      description='Command line script checking if your requirements are uptodate',
      author='Paweł Jastrzębski',
      author_email='pj@napcode.eu',
      url='https://gitlab.com/havk/uptodate',
      packages=packages,
      package_data=package_data,
      install_requires=install_requires,
      entry_points=entry_points,
     )
